fnss.netconfig.buffers.clear_buffer_sizes — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »

# fnss.netconfig.buffers.clear_buffer_sizes

`clear_buffer_sizes`(topology)

  Remove all buffer sizes from the topology.

  Parameters : | topology : Topology or DirectedTopology The topology whose buffer sizes are cleared

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »